# Copyright 2007 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


import os
import sys
import unittest

from testing import testcommon
from gvn import platform
from testing import tmpdir


class TestGvnPlatform(unittest.TestCase):

  def testDescribeSubprocessError(self):
    describe = platform.DescribeSubprocessError
    if sys.platform == 'win32':
      self.assertEquals(describe('command', 0x0100), "'command' exited 256")
      self.assertEquals(describe('command', 0x0002), "'command' exited 2")
      self.assertEquals(describe('command', 0x037f), "'command' exited 895")
    else:
      # Status LSB 00 == exited, 01-7E == signaled, 7F == stopped
      # Status MSB are the signal, for exited or stopped.
      self.assertEquals(describe('command', 0x0100), "'command' exited 1")
      self.assertEquals(describe('command', 0x0002),
                        "'command' killed with signal 2")
      self.assertEquals(describe('command', 0x037f),
                        "'command' stopped with signal 3")

  def test_rmtree(self):
    tree = tmpdir.RandomTmpSubdir()
    self.assertTrue(os.path.isdir(tree))
    subdir1 = os.path.join(tree, 'subdir1')
    os.mkdir(subdir1)
    fn = os.path.join(subdir1, 'file1')
    open(fn, 'w').write('Whee!\n')
    os.mkdir(os.path.join(tree, 'subdir2'))
    if sys.platform == 'win32':
      win32api = __import__('win32api')
      win32con = __import__('win32con')
      win32api.SetFileAttributes(tree, win32con.FILE_ATTRIBUTE_READONLY)
      win32api.SetFileAttributes(subdir1, win32con.FILE_ATTRIBUTE_READONLY)
      win32api.SetFileAttributes(fn, win32con.FILE_ATTRIBUTE_READONLY)
    self.assertTrue(os.path.isdir(tree))
    self.assertEquals(platform.rmtree(tree), None)
    self.assertFalse(os.path.isdir(tree))
