# Copyright 2007 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


import os
import shutil
import unittest

import gvn.platform

from testing import tmpdir


# We inherit runtest's tmpdir._TMPDIR; let's not clobber it :)
tmpdir._TMPDIR = None

class TestTmpDir(unittest.TestCase):

  def setUp(self):
    if tmpdir._TMPDIR is not None:
      gvn.platform.rmtree(tmpdir._TMPDIR)
    tmpdir._TMPDIR = None

  def test2TmpDir(self):
    tmp_dir = tmpdir.TmpDir()
    self.assert_(os.path.exists(tmp_dir))
    self.assertEquals(tmp_dir, tmpdir.TmpDir())

  def test3RandomTmpSubdir(self):
    tmp_dir1 = tmpdir.RandomTmpSubdir()
    self.assert_(os.path.exists(tmp_dir1))
    tmp_dir2 = tmpdir.RandomTmpSubdir()
    self.assert_(os.path.exists(tmp_dir2))
    self.assertNotEquals(tmp_dir1, tmp_dir2)

  def test4TmpSubdir(self):
    tmp_dir = tmpdir.TmpDir()
    subdirname = "i_am_subdir"
    subdir = os.path.join(tmp_dir, subdirname)
    self.assert_(not os.path.exists(subdir))
    retsubdir = tmpdir.TmpSubdir(subdirname)
    self.assertEquals(subdir, retsubdir)
    self.assert_(os.path.exists(subdir))

  def test5RecursiveRmdir(self):
    tmp_dir = tmpdir.TmpDir()
    self.assert_(os.path.exists(tmp_dir))
    self.assertTrue(tmpdir.RecursiveRmdir(tmp_dir))
    self.assert_(not os.path.exists(tmp_dir))
    self.assertTrue(tmpdir.RecursiveRmdir(tmp_dir))
